@@ -56,7 +56,7 @@ struct pane {
 	int y; /* absolute y position of the window on the screen */
 	int width; /* absolute width of the window */
 	int height; /* absolute height of the window */
-	int pos; /* focused row position */
+	off_t pos; /* focused row position */
 	struct row *rows;
 	size_t nrows; /* total amount of rows */
 	int focused; /* has focus or not */
@@ -94,7 +94,7 @@ static struct statusbar statusbar;
 static struct pane panes[PaneLast];
 static struct scrollbar scrollbars[PaneLast]; /* each pane has a scrollbar */
 static struct win win;
-static int selpane;
+static size_t selpane;
 
 static struct termios tsave; /* terminal state at startup */
 static struct termios tcur;
@@ -119,7 +119,6 @@ static struct feed *curfeed;
 static size_t nfeeds; /* amount of feeds */
 
 static time_t comparetime;
-static unsigned long totalnew, totalcount;
 
 struct item {
 	char *fields[FieldLast];
@@ -336,7 +335,14 @@ resettitle(void)
 void
 updatetitle(void)
 {
-	printf("\x1b]2;(%lu/%lu) - sfeed_curses\x1b\\", totalnew, totalcount);
+	unsigned long totalnew = 0, total = 0;
+	size_t i;
+
+	for (i = 0; i < nfeeds; i++) {
+		totalnew += feeds[i].totalnew;
+		total += feeds[i].total;
+	}
+	printf("\x1b]2;(%lu/%lu) - sfeed_curses\x1b\\", totalnew, total);
 }
 
 void
@@ -416,7 +422,7 @@ init(void)
 }
 
 void
-pipeitem(struct item *item)
+pipeitem(const char *cmd, struct item *item)
 {
 	FILE *fp;
 	int i, pid, wpid;
@@ -428,7 +434,7 @@ pipeitem(struct item *item)
 		return;
 	case 0:
 		errno = 0;
-		if (!(fp = popen(piper, "we"))) {
+		if (!(fp = popen(cmd, "we"))) {
 			fputs("popen: ", stderr);
 			perror(NULL);
 			_exit(1);
@@ -439,7 +445,7 @@ pipeitem(struct item *item)
 			fputs(item->fields[i], fp);
 		}
 		fputc('\n', fp);
-		exit(pclose(fp));
+		_exit(pclose(fp));
 		break;
 	default:
 		while ((wpid = wait(NULL)) >= 0 && wpid != pid)
@@ -451,7 +457,7 @@ pipeitem(struct item *item)
 }
 
 void
-plumb(char *url)
+plumb(const char *cmd, char *url)
 {
 	switch (fork()) {
 	case -1:
@@ -460,7 +466,7 @@ plumb(char *url)
 	case 0:
 		dup2(devnullfd, 1);
 		dup2(devnullfd, 2);
-		if (execlp(plumber, plumber, url, NULL) < 0)
+		if (execlp(cmd, cmd, url, NULL) < 0)
 			_exit(1);
 	}
 }
@@ -567,7 +573,7 @@ pane_setendpos(struct pane *p)
 }
 
 void
-pane_scrollpage(struct pane *p, size_t pages)
+pane_scrollpage(struct pane *p, int pages)
 {
 	off_t pos;
 
@@ -938,7 +944,7 @@ feed_load(struct feed *f, FILE *fp)
 	p->rows = NULL;
 	p->nrows = 0;
 
-	if (feed_getitems(f, f->fp, &items, &nitems) == -1)
+	if (feed_getitems(f, fp, &items, &nitems) == -1)
 		err(1, "%s: %s", __func__, f->path);
 
 	f->totalnew = 0;
@@ -1020,7 +1026,6 @@ void
 feeds_load(struct feed *feeds, size_t nfeeds)
 {
 	struct feed *f;
-	FILE *fp;
 	size_t i;
 
 	if ((comparetime = time(NULL)) == -1)
@@ -1028,7 +1033,6 @@ feeds_load(struct feed *feeds, size_t nfeeds)
 	/* 1 day is old news */
 	comparetime -= 86400;
 
-	totalnew = totalcount = 0;
 	for (i = 0; i < nfeeds; i++) {
 		f = &feeds[i];
 		f->totalnew = f->total = 0;
@@ -1057,9 +1061,6 @@ feeds_load(struct feed *feeds, size_t nfeeds)
 			fclose(f->fp);
 			f->fp = NULL;
 		}
-
-		totalnew += f->totalnew;
-		totalcount += f->total;
 	}
 }
 
@@ -1069,8 +1070,8 @@ updatesidebar(int onlynew)
 	struct pane *p;
 	struct row *row;
 	struct feed *feed;
-	size_t i, len;
-	int width;
+	size_t i;
+	int len, width;
 
 	p = &panes[PaneFeeds];
 
@@ -1198,12 +1199,15 @@ mousereport(int button, int release, int x, int y)
 				f = (struct feed *)row->data;
 				feeds_set(f);
 				feed_load(f, f->fp);
+				/* redraw row: counts could be changed */
+				pane_row_draw(p, pos);
+				updatetitle();
 			} else if (i == PaneItems) {
 				/* clicking the same highlighted row */
 				if (p->pos == pos && !changedpane) {
 					row = pane_row_get(&panes[PaneItems], pos);
 					item = (struct item *)row->data;
-					plumb(item->fields[FieldLink]);
+					plumb(plumber, item->fields[FieldLink]);
 				} else {
 					pane_setpos(p, pos);
 				}
@@ -1217,7 +1221,7 @@ mousereport(int button, int release, int x, int y)
 				p = &panes[PaneItems];
 				row = pane_row_get(p, p->pos);
 				item = (struct item *)row->data;
-				pipeitem(item);
+				pipeitem(piper, item);
 			}
 			break;
 		case 3: /* scroll up */
@@ -1241,12 +1245,12 @@ feed_row_format(struct pane *p, struct row *row)
 	feed = (struct feed *)row->data;
 
 	if (p->width) {
-		len = snprintf(counts, sizeof(counts), "(%ld/%ld)",
+		len = snprintf(counts, sizeof(counts), "(%lu/%lu)",
 		               feed->totalnew, feed->total);
 		utf8pad(bufw, sizeof(bufw), feed->name, p->width - len, ' ');
 		snprintf(text, sizeof(text), "%s%s", bufw, counts);
 	} else {
-		snprintf(text, sizeof(text), "%s (%ld/%ld)",
+		snprintf(text, sizeof(text), "%s (%lu/%lu)",
 		         feed->name, feed->totalnew, feed->total);
 	}
 
@@ -1266,7 +1270,7 @@ feed_row_match(struct pane *p, struct row *row, const char *s)
 struct row *
 item_row_get(struct pane *p, off_t pos)
 {
-	struct row *feedrow, *itemrow;
+	struct row *itemrow;
 	struct item *item;
 	struct feed *f;
 	char *dupline, *line = NULL;
@@ -1317,16 +1321,6 @@ item_row_format(struct pane *p, struct row *row)
 	return text;
 }
 
-int
-item_row_match(struct pane *p, struct row *row, const char *s)
-{
-	struct item *item;
-
-	item = (struct item *)row->data;
-
-	return (strcasestr(item->fields[FieldTitle], s) != NULL);
-}
-
 int
 main(int argc, char *argv[])
 {
@@ -1545,11 +1539,10 @@ nextpage:
 		case 'e': /* enclosure */
 		case '@':
 			if (selpane == PaneItems && panes[PaneItems].nrows) {
-				p = &panes[PaneFeeds];
 				p = &panes[PaneItems];
 				row = pane_row_get(p, p->pos);
 				item = (struct item *)row->data;
-				plumb(item->fields[FieldEnclosure]);
+				plumb(plumber, item->fields[FieldEnclosure]);
 			}
 			break;
 		case 'm': /* toggle mouse mode */
@@ -1577,22 +1570,30 @@ nextpage:
 				f = (struct feed *)row->data;
 				feeds_set(f);
 				feed_load(f, f->fp);
+				/* redraw row: counts could be changed */
+				pane_row_draw(p, p->pos);
+				updatetitle();
 			} else if (selpane == PaneItems && panes[PaneItems].nrows) {
 				p = &panes[PaneItems];
 				row = pane_row_get(p, p->pos);
 				item = (struct item *)row->data;
-				plumb(item->fields[FieldLink]);
+				plumb(plumber, item->fields[FieldLink]);
 			}
 			break;
 		case 'c': /* items: pipe TSV line to program */
 		case 'p':
 		case '|':
+		case 'y': /* yank: pipe TSV line to yank url to clipboard */
+		case 'E': /* yank: pipe TSV line to yank enclosure to clipboard */
 			if (selpane == PaneItems && panes[PaneItems].nrows) {
-				p = &panes[PaneFeeds];
 				p = &panes[PaneItems];
 				row = pane_row_get(p, p->pos);
 				item = (struct item *)row->data;
-				pipeitem(item);
+				switch (ch) {
+				case 'y': pipeitem("cut -f 3 | xclip -r", item); break;
+				case 'E': pipeitem("cut -f 8 | xclip -r", item); break;
+				default:  pipeitem(piper, item); break;
+				}
 			}
 			break;
 		case 4: /* EOT */
